@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 from plone.i18n.normalizer.base import allowed
 from plone.i18n.normalizer.interfaces import INormalizer
 from zope.interface import implementer
@@ -11,7 +10,7 @@ TABLE_LEN = len(TABLE)
 
 
 def _gethashed(obj, n):
-    num = hash(obj) % (TABLE_LEN ** n)
+    num = hash(obj) % (TABLE_LEN**n)
     while True:
         d, m = divmod(num, TABLE_LEN)
         num = d
@@ -27,13 +26,14 @@ def ja_normalize(text, max_length=MAX_LENGTH):
     """
     text = text.strip()
     if all(s in allowed for s in text):
-        return text.encode('ascii')
+        exchanged = text
     else:
-        return "".join(_gethashed(text, max_length))
+        exchanged = "".join(_gethashed(text, max_length))
+    return exchanged
 
 
 @implementer(INormalizer)
-class Normalizer(object):
+class Normalizer:
     """
     This normalizer can normalize any unicode string and returns a version
     that only contains of ASCII characters.
@@ -48,23 +48,27 @@ class Normalizer(object):
 
       >>> norm = Normalizer()
       >>> text = u"test page"
-      >>> norm.normalize(text) == b'test page'
-      True
+      >>> norm.normalize(text)
+      'test page'
 
     Text that contains non-ASCII characters are normalized.
 
       >>> norm = Normalizer()
-      >>> text = u"テストページ"
+      >>> text = u"公開テストページ"
       >>> normalized = norm.normalize(text)
       >>> all(s in allowed for s in normalized)
       True
-      >>> len(normalized)
-      6
+
+    We expect the default length of 6.
+    Report the normalized value in case of failure.
+
+      >>> 5 <= len(normalized) <= 6 or (len(normalized), normalized)
+      True
 
     The max_length argument is respected.
       >>> normalized = norm.normalize(text, max_length=8)
-      >>> len(normalized)
-      8
+      >>> 7 <= len(normalized) <= 8 or (len(normalized), normalized)
+      True
     """
 
     def normalize(self, text, locale=None, max_length=MAX_LENGTH):
