@@ -2,11 +2,11 @@ from plone.app.testing import setRoles
 from plone.app.testing import TEST_USER_ID
 from plone.app.testing import TEST_USER_NAME
 from plone.app.testing import TEST_USER_PASSWORD
+from plone.base.interfaces import ILanguage
 from plone.i18n.interfaces import ILanguageSchema
 from plone.i18n.tests import base
 from plone.registry.interfaces import IRegistry
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.interfaces import ILanguage
 from zope.component import getUtility
 
 
@@ -50,7 +50,6 @@ class TestNoCombinedLanguageNegotiation(LanguageNegotiationTestCase):
         self.settings.display_flags = 0
 
     def testLanguageNegotiation(self):
-
         # Test simple supported codes
         response = self.publish(
             self.portal_path,
@@ -90,7 +89,6 @@ class TestCombinedLanguageNegotiation(LanguageNegotiationTestCase):
         self.settings.display_flags = 0
 
     def testLanguageNegotiation(self):
-
         # Test simple supported codes
         response = self.publish(
             self.portal_path,
@@ -260,7 +258,7 @@ class TestCcTLDLanguageNegotiation(LanguageNegotiationTestCase):
         self.checkLanguage(response, "nl")
 
     def testAcceptedLanguages(self):
-        # Brazil uses Portugese, which is not in the accepted languages list
+        # Brazil uses Portuguese, which is not in the accepted languages list
         response = self.publish(
             self.portal_path,
             self.basic_auth,
@@ -328,7 +326,7 @@ class TestSubdomainLanguageNegotiation(LanguageNegotiationTestCase):
         self.checkLanguage(response, "nl")
 
     def testAcceptedLanguages(self):
-        # Brazil uses Portugese, which is not in the accepted languages list
+        # Brazil uses Portuguese, which is not in the accepted languages list
         response = self.publish(
             self.portal_path,
             self.basic_auth,
